Skip to contents

Predict calves per adult female by year as trend line. Recruitment fit object provided must be created with year_trend = TRUE.

Usage

bb_predict_calf_cow_ratio_trend_samples(recruitment)

Arguments

recruitment

An object of class 'bboufit_recruitment' (output of bb_fit_recruitment())

Value

A list with elements:

  • samples: An mcmcarray with the MCMC samples.

  • data: A data.frame containing the associated prediction data.