Predict Calf-Cow Ratio Trend Samples
Source:R/predict-trend.R
bb_predict_calf_cow_ratio_trend_samples.RdPredict calves per adult female by year as trend line.
Recruitment fit object provided must be created with year_trend = TRUE.
Arguments
- recruitment
An object of class 'bboufit_recruitment' (output of
bb_fit_recruitment())
Value
A list with elements:
samples: Anmcmcarraywith the MCMC samples.data: Adata.framecontaining the associated prediction data.
See also
Other analysis:
bb_predict_calf_cow_ratio(),
bb_predict_calf_cow_ratio_samples(),
bb_predict_calf_cow_ratio_trend(),
bb_predict_growth(),
bb_predict_growth_samples(),
bb_predict_population_change(),
bb_predict_population_change_samples(),
bb_predict_recruitment(),
bb_predict_recruitment_samples(),
bb_predict_recruitment_trend(),
bb_predict_recruitment_trend_samples(),
bb_predict_survival(),
bb_predict_survival_samples(),
bb_predict_survival_trend(),
bb_predict_survival_trend_samples()